@@ -59,6 +59,76 @@ static guint32 fs_mode_util[BD_FS_MODE_LAST+1] = {
 
 #define UNUSED __attribute__((unused))
 
+static gint8 compute_percents (guint8 pass_cur, guint8 pass_total, gint val_cur, gint val_total) {
+    gint perc;
+    gint one_pass;
+    /* first get a percentage in the current pass/stage */
+    perc = (val_cur * 100) / val_total;
+
+    /* now map it to the total progress, splitting the stages equally */
+    one_pass = 100 / pass_total;
+    perc = ((pass_cur - 1) * one_pass) + (perc / pass_total);
+
+    return perc;
+}
+
+/**
+ * filter_line_fsck: (skip)
+ * Filter one line - decide what to do with it.
+ *
+ * Returns: Zero or positive number as a percentage, -1 if not a percentage, -2 on an error
+ */
+static gint8 filter_line_fsck (const gchar * line, guint8 total_stages, GError **error) {
+    static GRegex *output_regex = NULL;
+    GMatchInfo *match_info;
+    gint8 perc = -1;
+
+    if (output_regex == NULL) {
+        /* Compile regular expression that matches to e2fsck progress output */
+        output_regex = g_regex_new ("^([0-9][0-9]*) ([0-9][0-9]*) ([0-9][0-9]*) (/.*)", 0, 0, error);
+        if (output_regex == NULL) {
+            return -2;
+        }
+    }
+
+    /* Execute regular expression */
+    if (g_regex_match (output_regex, line, 0, &match_info)) {
+        guint8 stage;
+        gint64 val_cur;
+        gint64 val_total;
+
+        /* The output_regex ensures we have a number in these matches, so we can skip
+         * tests for conversion errors.
+         */
+        stage = (guint8) g_ascii_strtoull (g_match_info_fetch (match_info, 1), (char **)NULL, 10);
+        val_cur = g_ascii_strtoll (g_match_info_fetch (match_info, 2), (char **)NULL, 10);
+        val_total = g_ascii_strtoll (g_match_info_fetch (match_info, 3), (char **)NULL, 10);
+        perc = compute_percents (stage, total_stages, val_cur, val_total);
+    } else {
+        g_match_info_free (match_info);
+        return -1;
+    }
+    g_match_info_free (match_info);
+    return perc;
+}
+
+static gboolean extract_e2fsck_progress (const gchar *line, guint8 *completion) {
+    /* A magic number 5, e2fsck has 5 stages, but this can't be read from the output in advance. */
+    gint8 perc;
+    GError **error = NULL;
+
+    perc = filter_line_fsck (line, 5, error);
+    if (perc < 0) {
+        g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_FAIL,
+                         "An error occured when trying to parse a line with progress");
+        return FALSE;
+    }
+
+    *completion = perc;
+    return TRUE;
+}
+
+
 /**
  * bd_fs_ext_is_tech_avail:
  * @tech: the queried tech
@@ -244,6 +314,7 @@ static gboolean ext_check (const gchar *device, const BDExtraArg **extra, GError
     /* Force checking even if the file system seems clean. AND
      * Open the filesystem read-only, and assume an answer of no to all
      * questions. */
+    const gchar *args_progress[7] = {"e2fsck", "-f", "-n", "-C", "1", device, NULL};
     const gchar *args[5] = {"e2fsck", "-f", "-n", device, NULL};
     gint status = 0;
     gboolean ret = FALSE;
@@ -251,7 +322,12 @@ static gboolean ext_check (const gchar *device, const BDExtraArg **extra, GError
     if (!check_deps (&avail_deps, DEPS_E2FSCK_MASK, deps, DEPS_LAST, &deps_check_lock, error))
         return FALSE;
 
-    ret = bd_utils_exec_and_report_status_error (args, extra, &status, error);
+    if (bd_utils_prog_reporting_initialized ()) {
+        ret = bd_utils_exec_and_report_progress (args_progress, extra, extract_e2fsck_progress, &status, error);
+    } else {
+        ret = bd_utils_exec_and_report_status_error (args, extra, &status, error);
+    }
+
     if (!ret && (status == 4)) {
         /* no error should be reported for exit code 4 - File system errors left uncorrected */
         g_clear_error (error);
@@ -308,12 +384,18 @@ static gboolean ext_repair (const gchar *device, gboolean unsafe, const BDExtraA
     /* Force checking even if the file system seems clean. AND
      *     Automatically repair what can be safely repaired. OR
      *     Assume an answer of `yes' to all questions. */
+    const gchar *args_progress[7] = {"e2fsck", "-f", "-n", "-C", "1", device, NULL};
     const gchar *args[5] = {"e2fsck", "-f", unsafe ? "-y" : "-p", device, NULL};
+    gint status = 0;
 
     if (!check_deps (&avail_deps, DEPS_E2FSCK_MASK, deps, DEPS_LAST, &deps_check_lock, error))
         return FALSE;
 
-    return bd_utils_exec_and_report_error (args, extra, error);
+    if (bd_utils_prog_reporting_initialized ()) {
+        return bd_utils_exec_and_report_progress (args_progress, extra, extract_e2fsck_progress, &status, error);
+    } else {
+        return bd_utils_exec_and_report_status_error (args, extra, &status, error);
+    }
 }
 
 /**
