@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014  Red Hat, Inc.
+ * Copyright (C) 2014-2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,11 @@
 #include <glib.h>
 #include <string.h>
 #include <unistd.h>
-#include <utils.h>
+#include <sys/swap.h>
+#include <blockdev/utils.h>
+
 #include "swap.h"
+#include "check_deps.h"
 
 /**
  * SECTION: swap
@@ -40,53 +43,118 @@ GQuark bd_swap_error_quark (void)
     return g_quark_from_static_string ("g-bd-swap-error-quark");
 }
 
+
+static volatile guint avail_deps = 0;
+static GMutex deps_check_lock;
+
+#define DEPS_MKSWAP 0
+#define DEPS_MKSWAP_MASK (1 << DEPS_MKSWAP)
+#define DEPS_SWAPLABEL 1
+#define DEPS_SWAPLABEL_MASK (1 << DEPS_SWAPLABEL)
+#define DEPS_LAST 2
+
+static UtilDep deps[DEPS_LAST] = {
+    {"mkswap", MKSWAP_MIN_VERSION, NULL, "mkswap from util-linux ([\\d\\.]+)"},
+    {"swaplabel", NULL, NULL, NULL},
+};
+
+
 /**
- * check: (skip)
+ * bd_swap_check_deps:
+ *
+ * Returns: whether the plugin's runtime dependencies are satisfied or not
+ *
+ * Function checking plugin's runtime dependencies.
+ *
  */
-gboolean check() {
+gboolean bd_swap_check_deps () {
     GError *error = NULL;
-    gboolean ret = bd_utils_check_util_version ("mkswap", MKSWAP_MIN_VERSION, NULL, "mkswap from util-linux ([\\d\\.]+)", &error);
+    guint i = 0;
+    gboolean status = FALSE;
+    gboolean ret = TRUE;
 
-    if (!ret && error) {
-        g_warning("Cannot load the swap plugin: %s" , error->message);
+    for (i=0; i < DEPS_LAST; i++) {
+        status = bd_utils_check_util_version (deps[i].name, deps[i].version,
+                                              deps[i].ver_arg, deps[i].ver_regexp, &error);
+        if (!status)
+            g_warning ("%s", error->message);
+        else
+            g_atomic_int_or (&avail_deps, 1 << i);
         g_clear_error (&error);
+        ret = ret && status;
     }
 
     if (!ret)
-        return FALSE;
-
-    ret = bd_utils_check_util_version ("swapon", SWAPON_MIN_VERSION, NULL, "swapon from util-linux ([\\d\\.]+)", &error);
-    if (!ret && error) {
-        g_warning("Cannot load the swap plugin: %s" , error->message);
-        g_clear_error (&error);
-    }
-
-    if (!ret)
-        return FALSE;
-
-    ret = bd_utils_check_util_version ("swapoff", SWAPOFF_MIN_VERSION, NULL, "swapoff from util-linux ([\\d\\.]+)", &error);
-    if (!ret && error) {
-        g_warning("Cannot load the swap plugin: %s" , error->message);
-        g_clear_error (&error);
-    }
+        g_warning("Cannot load the swap plugin");
 
     return ret;
 }
 
+/**
+ * bd_swap_init:
+ *
+ * Initializes the plugin. **This function is called automatically by the
+ * library's initialization functions.**
+ *
+ */
+gboolean bd_swap_init () {
+    /* nothing to do here */
+    return TRUE;
+};
+
+/**
+ * bd_swap_close:
+ *
+ * Cleans up after the plugin. **This function is called automatically by the
+ * library's functions that unload it.**
+ *
+ */
+void bd_swap_close () {
+    /* nothing to do here */
+}
+
+#define UNUSED __attribute__((unused))
+
+/**
+ * bd_swap_is_tech_avail:
+ * @tech: the queried tech
+ * @mode: a bit mask of queried modes of operation (#BDSwapTechMode) for @tech
+ * @error: (out): place to store error (details about why the @tech-@mode combination is not available)
+ *
+ * Returns: whether the @tech-@mode combination is available -- supported by the
+ *          plugin implementation and having all the runtime dependencies available
+ */
+gboolean bd_swap_is_tech_avail (BDSwapTech tech UNUSED, guint64 mode, GError **error) {
+    guint32 requires = 0;
+    if (mode & BD_SWAP_TECH_MODE_CREATE)
+        requires |= DEPS_MKSWAP_MASK;
+    if (mode & BD_SWAP_TECH_MODE_SET_LABEL)
+        requires |= DEPS_SWAPLABEL_MASK;
+
+    return check_deps (&avail_deps, requires, deps, DEPS_LAST, &deps_check_lock, error);
+}
+
 /**
  * bd_swap_mkswap:
  * @device: a device to create swap space on
  * @label: (allow-none): a label for the swap space device
+ * @extra: (allow-none) (array zero-terminated=1): extra options for the creation (right now
+ *                                                 passed to the 'mkswap' utility)
  * @error: (out): place to store error (if any)
  *
  * Returns: whether the swap space was successfully created or not
+ *
+ * Tech category: %BD_SWAP_TECH_SWAP-%BD_SWAP_TECH_MODE_CREATE
  */
-gboolean bd_swap_mkswap (gchar *device, gchar *label, GError **error) {
+gboolean bd_swap_mkswap (const gchar *device, const gchar *label, const BDExtraArg **extra, GError **error) {
     guint8 next_arg = 2;
 
+    if (!check_deps (&avail_deps, DEPS_MKSWAP_MASK, deps, DEPS_LAST, &deps_check_lock, error))
+        return FALSE;
+
     /* We use -f to force since mkswap tends to refuse creation on lvs with
        a message about erasing bootbits sectors on whole disks. Bah. */
-    gchar *argv[6] = {"mkswap", "-f", NULL, NULL, NULL, NULL};
+    const gchar *argv[6] = {"mkswap", "-f", NULL, NULL, NULL, NULL};
 
     if (label) {
         argv[next_arg] = "-L";
@@ -97,7 +165,7 @@ gboolean bd_swap_mkswap (gchar *device, gchar *label, GError **error) {
 
     argv[next_arg] = device;
 
-    return bd_utils_exec_and_report_error (argv, error);
+    return bd_utils_exec_and_report_error (argv, extra, error);
 }
 
 /**
@@ -107,11 +175,10 @@ gboolean bd_swap_mkswap (gchar *device, gchar *label, GError **error) {
  * @error: (out): place to store error (if any)
  *
  * Returns: whether the swap device was successfully activated or not
+ *
+ * Tech category: %BD_SWAP_TECH_SWAP-%BD_SWAP_TECH_MODE_ACTIVATE_DEACTIVATE
  */
-gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
-    gboolean success = FALSE;
-    guint8 next_arg = 1;
-    guint8 to_free_idx = 0;
+gboolean bd_swap_swapon (const gchar *device, gint priority, GError **error) {
     GIOChannel *dev_file = NULL;
     GIOStatus io_status = G_IO_STATUS_ERROR;
     GError *tmp_error = NULL;
@@ -119,13 +186,22 @@ gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
     gchar dev_status[11];
     dev_status[10] = '\0';
     gint page_size;
+    gint flags = 0;
+    gint ret = 0;
+    guint64 progress_id = 0;
+    gchar *msg = NULL;
 
-    gchar *argv[5] = {"swapon", NULL, NULL, NULL, NULL};
+    msg = g_strdup_printf ("Started 'swapon %s'", device);
+    progress_id = bd_utils_report_started (msg);
+    g_free (msg);
 
+
+    bd_utils_report_progress (progress_id, 0, "Analysing the swap device");
     /* check the device if it is an activatable swap */
     dev_file = g_io_channel_new_file (device, "r", error);
     if (!dev_file) {
         /* error is already populated */
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     }
 
@@ -137,6 +213,7 @@ gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
                      "Failed to determine device's state: %s", tmp_error->message);
         g_clear_error (&tmp_error);
         g_io_channel_shutdown (dev_file, FALSE, &tmp_error);
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     }
 
@@ -147,6 +224,7 @@ gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
         g_clear_error (&tmp_error);
         g_io_channel_shutdown (dev_file, FALSE, &tmp_error);
         g_clear_error (&tmp_error);
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     }
 
@@ -156,33 +234,35 @@ gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
     if (g_str_has_prefix (dev_status, "SWAP-SPACE")) {
         g_set_error (error, BD_SWAP_ERROR, BD_SWAP_ERROR_ACTIVATE,
                      "Old swap format, cannot activate.");
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     } else if (g_str_has_prefix (dev_status, "S1SUSPEND") || g_str_has_prefix (dev_status, "S2SUSPEND")) {
         g_set_error (error, BD_SWAP_ERROR, BD_SWAP_ERROR_ACTIVATE,
                      "Suspended system on the swap device, cannot activate.");
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     } else if (!g_str_has_prefix (dev_status, "SWAPSPACE2")) {
         g_set_error (error, BD_SWAP_ERROR, BD_SWAP_ERROR_ACTIVATE,
                      "Unknown swap space format, cannot activate.");
+        bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
     }
 
+    bd_utils_report_progress (progress_id, 10, "Swap device analysed, enabling");
     if (priority >= 0) {
-        argv[next_arg] = "-p";
-        next_arg++;
-        to_free_idx = next_arg;
-        argv[next_arg] = g_strdup_printf ("%d", priority);
-        next_arg++;
+        flags = SWAP_FLAG_PREFER;
+        flags |= (priority << SWAP_FLAG_PRIO_SHIFT) & SWAP_FLAG_PRIO_MASK;
     }
 
-    argv[next_arg] = device;
+    ret = swapon (device, flags);
+    if (ret != 0) {
+        g_set_error (error, BD_SWAP_ERROR, BD_SWAP_ERROR_ACTIVATE,
+                     "Failed to activate swap on %s: %m", device);
+        bd_utils_report_finished (progress_id, (*error)->message);
+    }
 
-    success = bd_utils_exec_and_report_error (argv, error);
-
-    if (to_free_idx > 0)
-        g_free (argv[to_free_idx]);
-
-    return success;
+    bd_utils_report_finished (progress_id, "Completed");
+    return ret == 0;
 }
 
 /**
@@ -191,12 +271,27 @@ gboolean bd_swap_swapon (gchar *device, gint priority, GError **error) {
  * @error: (out): place to store error (if any)
  *
  * Returns: whether the swap device was successfully deactivated or not
+ *
+ * Tech category: %BD_SWAP_TECH_SWAP-%BD_SWAP_TECH_MODE_ACTIVATE_DEACTIVATE
  */
-gboolean bd_swap_swapoff (gchar *device, GError **error) {
-    gchar *argv[3] = {"swapoff", NULL, NULL};
-    argv[1] = device;
+gboolean bd_swap_swapoff (const gchar *device, GError **error) {
+    gint ret = 0;
+    guint64 progress_id = 0;
+    gchar *msg = NULL;
 
-    return bd_utils_exec_and_report_error (argv, error);
+    msg = g_strdup_printf ("Started 'swapoff %s'", device);
+    progress_id = bd_utils_report_started (msg);
+    g_free (msg);
+
+    ret = swapoff (device);
+    if (ret != 0) {
+        g_set_error (error, BD_SWAP_ERROR, BD_SWAP_ERROR_ACTIVATE,
+                     "Failed to deactivate swap on %s: %m", device);
+        bd_utils_report_finished (progress_id, (*error)->message);
+    }
+
+    bd_utils_report_finished (progress_id, "Completed");
+    return ret == 0;
 }
 
 /**
@@ -206,11 +301,13 @@ gboolean bd_swap_swapoff (gchar *device, GError **error) {
  *
  * Returns: %TRUE if the swap device is active, %FALSE if not active or failed
  * to determine (@error) is set not a non-NULL value in such case)
+ *
+ * Tech category: %BD_SWAP_TECH_SWAP-%BD_SWAP_TECH_MODE_QUERY
  */
-gboolean bd_swap_swapstatus (gchar *device, GError **error) {
+gboolean bd_swap_swapstatus (const gchar *device, GError **error) {
     gchar *file_content;
     gchar *real_device = NULL;
-    gchar *symlink = NULL;
+    gchar *dev_path = NULL;
     gsize length;
     gchar *next_line;
     gboolean success;
@@ -222,21 +319,21 @@ gboolean bd_swap_swapstatus (gchar *device, GError **error) {
     }
 
     /* get the real device node for device-mapper devices since the ones
-       with meaningful names are just symlinks */
+       with meaningful names are just dev_paths */
     if (g_str_has_prefix (device, "/dev/mapper/") || g_str_has_prefix (device, "/dev/md/")) {
-        symlink = g_file_read_link (device, error);
-        if (!symlink) {
+        dev_path = bd_utils_resolve_device (device, error);
+        if (!dev_path) {
             /* the device doesn't exist and thus is not an active swap */
             g_clear_error (error);
             return FALSE;
         }
 
-        /* the symlink starts with "../" */
-        real_device = g_strdup_printf ("/dev/%s", symlink + 3);
+        /* the dev_path starts with "../" */
+        real_device = g_strdup_printf ("/dev/%s", dev_path + 3);
     }
 
     if (g_str_has_prefix (file_content, real_device ? real_device : device)) {
-        g_free (symlink);
+        g_free (dev_path);
         g_free (real_device);
         g_free (file_content);
         return TRUE;
@@ -245,7 +342,7 @@ gboolean bd_swap_swapstatus (gchar *device, GError **error) {
     next_line = (strchr (file_content, '\n') + 1);
     while (next_line && ((gsize)(next_line - file_content) < length)) {
         if (g_str_has_prefix (next_line, real_device ? real_device : device)) {
-            g_free (symlink);
+            g_free (dev_path);
             g_free (real_device);
             g_free (file_content);
             return TRUE;
@@ -254,8 +351,27 @@ gboolean bd_swap_swapstatus (gchar *device, GError **error) {
         next_line = (strchr (next_line, '\n') + 1);
     }
 
-    g_free (symlink);
+    g_free (dev_path);
     g_free (real_device);
     g_free (file_content);
     return FALSE;
 }
+
+/**
+ * bd_swap_set_label:
+ * @device: a device to set label on
+ * @label: label that will be set
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether the label was successfully set or not
+ *
+ * Tech category: %BD_SWAP_TECH_SWAP-%BD_SWAP_TECH_MODE_SET_LABEL
+ */
+gboolean bd_swap_set_label (const gchar *device, const gchar *label, GError **error) {
+    const gchar *argv[5] = {"swaplabel", "-L", label, device, NULL};
+
+    if (!check_deps (&avail_deps, DEPS_SWAPLABEL_MASK, deps, DEPS_LAST, &deps_check_lock, error))
+        return FALSE;
+
+    return bd_utils_exec_and_report_error (argv, NULL, error);
+}
