@@ -3,6 +3,9 @@
 
 #include "sizes.h"
 #include "exec.h"
+#include "extra_arg.h"
+#include "dev_utils.h"
+#include "module.h"
 
 /**
  * SECTION: utils
